aboutsummaryrefslogtreecommitdiff
path: root/build2/cxx
diff options
context:
space:
mode:
authorBoris Kolpackov <boris@codesynthesis.com>2019-05-03 13:23:33 +0200
committerBoris Kolpackov <boris@codesynthesis.com>2019-05-03 13:23:33 +0200
commit8618078b90189fb49e9c0a76ac01d471b51f1e93 (patch)
tree63ee0435f3311d90d5863ca49a3dc0e5807bb097 /build2/cxx
parent43c53a8b475f901a902ba1bf6ec603e7a28311b1 (diff)
Rename [config.]cxx.header_units to importable_headers
Diffstat (limited to 'build2/cxx')
-rw-r--r--build2/cxx/init.cxx10
1 files changed, 5 insertions, 5 deletions
diff --git a/build2/cxx/init.cxx b/build2/cxx/init.cxx
index 3fb636f..a04a30a 100644
--- a/build2/cxx/init.cxx
+++ b/build2/cxx/init.cxx
@@ -394,16 +394,16 @@ namespace build2
v.insert<strings> ("config.cxx.loptions", true),
v.insert<strings> ("config.cxx.libs", true),
// List of modular headers. Inclusion of such headers is translated to
// the corresponding header unit imports.
//
// A header can be specified either as an absolute and normalized path
// or as a <>-style include name. The latter kind is automatically
// translated to the absolute form based on the include search paths
// extracted from the compiler. Note also that all entries must be
- // specified before loading the module.
+ // specified before loading the cxx module.
//
- &v.insert<strings> ("config.cxx.header_units", true),
+ &v.insert<strings> ("config.cxx.importable_headers", true),
v.insert<process_path> ("cxx.path"),
v.insert<dir_paths> ("cxx.sys_lib_dirs"),
@@ -413,7 +413,7 @@ namespace build2
v.insert<strings> ("cxx.coptions"),
v.insert<strings> ("cxx.loptions"),
v.insert<strings> ("cxx.libs"),
- &v.insert<strings> ("cxx.header_units"),
+ &v.insert<strings> ("cxx.importable_headers"),
v["cc.poptions"],
v["cc.coptions"],
@@ -394,16 +394,16 @@ namespace build2
v.insert<strings> ("config.cxx.loptions", true),
v.insert<strings> ("config.cxx.libs", true),
- // List of modular headers. Inclusion of such headers is translated to
- // the corresponding header unit imports.
+ // List of importable headers. Inclusion of such headers is translated
+ // to the corresponding header unit imports.
//
// A header can be specified either as an absolute and normalized path